@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.31 2004/11/13 21:08:05 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.33 2005/09/07 18:50:33 werner Exp $
  *
  * Diverse Hilfsfunktionen
  *
@@ -423,6 +423,11 @@ void PrintMenuOptions(WINDOW *win,int y, int x, char *str, int ncolor, int hcolo
 {
   int ch;
   int color, hi_color, lo_color;
+  char *sbuf, buf[2];
+  
+  sbuf = (char *)malloc(strlen(str)+1);
+  sbuf[0] = '\0';
+  buf[1] = '\0';
 
   if(x < 0 || y < 0) {
      /* screen too small */
@@ -438,37 +443,58 @@ void PrintMenuOptions(WINDOW *win,int y, int x, char *str, int ncolor, int hcolo
 #endif
    
   color = lo_color;
+  wmove(win, y, x);
 
   for( ; *str; str++ )
   {
     ch = (int) *str;
    
     switch( ch ) {
-        case '(': color = hi_color;  continue;
-	case ')': color = lo_color;  continue;
+        case '(': color = hi_color;
+#ifdef COLOR_SUPPORT
+                  WAttrAddStr( win, COLOR_PAIR(color) | A_BOLD, sbuf);
+#else
+                  WAttrAddStr( win, color, sbuf);
+#endif
+		  strcpy(sbuf, "");
+	          continue;
+		  
+	case ')': color = lo_color;
+#ifdef COLOR_SUPPORT
+                  WAttrAddStr( win, COLOR_PAIR(color) | A_BOLD, sbuf);
+#else
+                  WAttrAddStr( win, color, sbuf);
+#endif
+		  strcpy(sbuf, "");
+	          continue;
 
 #ifdef COLOR_SUPPORT
-	case ']': color = lo_color;  continue;
-	case '[': color = hi_color;  continue;
+	case ']': color = lo_color;
+                  WAttrAddStr( win, COLOR_PAIR(color) | A_BOLD, sbuf);
+		  strcpy(sbuf, "");
+	          continue;
+	case '[': color = hi_color;
+                  WAttrAddStr( win, COLOR_PAIR(color) | A_BOLD, sbuf);
+		  strcpy(sbuf, "");
+	          continue;
 #else
 	case ']':
 	case '[': /* ignore */ continue;
 #endif
-        default : ch = PRINT(*str);
+        default : buf[0] = PRINT(*str);
+		  strcat(sbuf, buf);
     }
+  }    
 
 #ifdef COLOR_SUPPORT
-    wattrset( win, COLOR_PAIR(color) | A_BOLD);
+  WAttrAddStr( win, COLOR_PAIR(color) | A_BOLD, sbuf);
 #else
-    wattrset( win, color);
+  WAttrAddStr( win, color, sbuf);
 #endif
-    mvwaddch(win, y, x++, ch );
-    wattrset( win, 0 );
-  }
+  free(sbuf);
 }
 
 
-
 /*****************************************************************************
  *                              FormFilename                                 *
  *****************************************************************************/
@@ -502,15 +528,17 @@ char *FormFilename(char *dest, char *src, unsigned int max_len)
 char *CutFilename(char *dest, char *src, unsigned int max_len)
 {
   unsigned int l;
+  char *tmp;
 
-  l = strlen(src);
+  l = StrVisualLength(src);
 
   if( l <= max_len )
     return( strcpy( dest, src ) );
   else
   {
-    (void) strncpy( dest, src, max_len - 3 );
-    (void) strcpy( &dest[max_len - 3], "..." );
+    tmp = StrLeft(src, max_len - 3);
+    sprintf(dest, "%s...", tmp);
+    free(tmp);
     return( dest );
   }
 }
@@ -816,13 +844,32 @@ int Strrcmp(char *s1, char* s2)/*compares in reverse order 2 strings*/
 
 
 /* NeXT does not define strdup */
-char *Strdup(char *s)
+char *Strdup(const char *s)
 {
   char *cp = NULL;
 
   if (s) {
     cp = malloc(strlen(s)+1);
-    if (cp) strcpy(cp,s);
+    if (cp) {
+      strcpy(cp,s);
+    }
+  }
+  return(cp);
+}
+
+/* Solaris does not define this */
+char *Strndup(const char *s, int len)
+{
+  char *cp = NULL;
+  int l;
+
+  if (s) {
+    l = MINIMUM(strlen(s), len);
+    cp = malloc(l+1);
+    if (cp) {
+      memcpy(cp, s, l);
+      cp[l] = '\0';
+    }
   }
   return(cp);
 }
