@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.36 2004/11/13 20:38:40 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.39 2005/09/07 18:50:33 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -45,6 +45,7 @@
 #include <sys/stat.h>
 #include <time.h>
 #if defined(linux) || defined(__GNU__)
+#include <locale.h>
 #include <sys/wait.h>
 #include <sys/time.h>	/* needed vor RedHed5 (thanks to Robert Spier) */
 #endif
@@ -78,6 +79,10 @@ extern char *getcwd();
 #include <termcap.h>
 #endif
 
+#ifdef WITH_UTF8
+#include <wchar.h>
+#endif
+
 #ifdef openbsd
 #define STATFS(a, b, c, d )     statfs( a, b )
 #define LONGLONG		long long
@@ -475,6 +480,7 @@ extern char *getcwd();
 #define FILE1         GetProfileValue( "FILE1" )
 #define FILE2         GetProfileValue( "FILE2" )
 #define SEARCHCOMMAND GetProfileValue( "SEARCHCOMMAND" )
+#define HEXEDITOFFSET GetProfileValue( "HEXEDITOFFSET" )
  
 
 #define DEFAULT_TREE       "."
@@ -1051,7 +1057,7 @@ extern int  WAddStr(WINDOW *win, char *str);
 extern int  AddStr(char *str);
 extern void ClockHandler(int);
 extern int Strrcmp(char *s1, char* s2);
-extern char *Strdup(char *s);
+extern char *Strdup(const char *s);
 extern char *GetExtViewer(char *filename);
 extern void InitClock(void);
 extern void SuspendClock(void);
@@ -1073,4 +1079,8 @@ extern char *GetUserDirAction(int chkey, int *pchremap);
 extern BOOL IsUserActionDefined(void);
 extern char *Getcwd(char *buffer, unsigned int len);
 extern int  RefreshDirWindow();
+extern char *StrLeft(const char *str, size_t count);
+extern int  StrVisualLength(const char *str);
+extern int  WAttrAddStr(WINDOW *win, int attr, char *str);
+extern char *Strndup(const char *s, int len);
 
